;; Generated package description from tmr.el  -*- no-byte-compile: t -*-
(define-package "tmr" "0.3.0" "Set timers using a convenient notation" '((emacs "27.1")) :commit "79a57fce5139f764eee1a7f1414e3075d4e1549b" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com") ("Damien Cassou" . "damien@cassou.me")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "timer") :url "https://git.sr.ht/~protesilaos/tmr")
